@@ -92,10 +92,8 @@ sub get_collapsed_comments {
 }
 
 sub reply {
-    	my ($self, $text) = @_;
-	$text || croak "need comment text";	
+    my ($self, $text) = @_;
 	my $cmtid = $self->{session}->submit_comment(parent_id=>$self->{name}, text=>$text);
-	return "t1_".$cmtid if $cmtid;
 	return $cmtid;
 }
 sub remove {
