@@ -38,11 +38,13 @@ crosspost_parent
 discussion_type
 distinguished
 domain
+gallery_data
 gilded
 gildings
 hidden
 hide_score
 is_crosspostable
+is_gallery
 is_meta
 is_reddit_media_domain
 is_robot_indexable
@@ -58,6 +60,7 @@ link_flair_type
 locked
 media
 media_embed
+media_metadata
 mod_reports
 morecomments
 num_comments
@@ -104,9 +107,7 @@ use constant type => "t3";
 
 sub reply {
     my ($self, $text) = @_;
-	$text || croak "need comment text";	
 	my $cmtid = $self->{session}->submit_comment(parent_id=>$self->{name}, text=>$text);
-	return "t1_".$cmtid if $cmtid;
 	return $cmtid;
 }
 sub remove {
