@@ -75,8 +75,7 @@ sub load_from_source_data {
                 $self->set_bool($field, $source_data->{$field});
             } else {
 	            eval { $self->{$field} = $source_data->{$field} };
-	            Reddit::Client::DEBUG("Field %s is missing from package %s\n", $field, ref $self)
-	                if $@;
+	            Reddit::Client::DEBUG("Field %s is missing from package %s\n", $field, ref $self) if $@;
             }
 
             # Add getter for field
